==> custom-toolbox_25.08.3.tar.xz: BUILD/translations/custom-toolbox_ru_RU.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.ui" line="20"/>
        <location filename="../src/mainwindow.cpp" line="198"/>
        <source>Custom Toolbox</source>
        <translation>Пользовательский набор инструментов</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="63"/>
        <source>About this application</source>
        <translation>Об этом приложении</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="66"/>
        <source>About...</source>
        <translation>О программе...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="73"/>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="89"/>
        <source>Customize launcher</source>
        <translation>Настроить лаунчер</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="92"/>
        <source>Edit</source>
        <translation>Правка</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="99"/>
        <source>Alt+E</source>
        <translation>Alt+E</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="163"/>
        <source>Help</source>
        <translation>Помощь</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="170"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="183"/>
        <source>Close application</source>
        <translation>Закрыть приложение</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="186"/>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="193"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="308"/>
        <source>This is a custom launcher</source>
        <translation>Это настраиваемый лаунчер</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="324"/>
        <source>Show this dialog at start up</source>
        <translation>Показывать этот диалог при запуске</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="346"/>
        <source>search</source>
        <translation>поиск</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="250"/>
        <location filename="../src/mainwindow.cpp" line="257"/>
        <source>Execution Error</source>
        <translation>Ошибка выполнения</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="250"/>
        <source>Failed to execute command: %1</source>
        <translation>Не удалось выполнить команду: %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="257"/>
        <source>Failed to start program: %1</source>
        <translation>Не удалось запустить программу: %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="297"/>
        <source>Open List File</source>
        <translation>Открыть файл списка</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="297"/>
        <source>List Files (*.list)</source>
        <translation>Файлы списка (*.list)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="299"/>
        <source>File Selection Error</source>
        <translation>Ошибка выбора файла</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="299"/>
        <source>No file selected. Application will now exit.</source>
        <translation>Файл не выбран. Завершение приложения.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="305"/>
        <location filename="../src/mainwindow.cpp" line="569"/>
        <location filename="../src/mainwindow.cpp" line="722"/>
        <source>File Open Error</source>
        <translation>Ошибка открытия файла</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="306"/>
        <source>Could not open file. Do you want to try again?</source>
        <translation>Не могу открыть файл. Хотите попробовать еще раз?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="561"/>
        <source>File Not Found</source>
        <translation>Файл не найден</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="561"/>
        <source>The file %1 does not exist.</source>
        <translation>Файл %1 не существует.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="569"/>
        <source>Could not open file: </source>
        <translation>Не удалось открыть файл:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="660"/>
        <source>Version:</source>
        <translation>Версия:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="663"/>
        <source>About %1</source>
        <translation>О %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="661"/>
        <source>Custom Toolbox is a tool used for creating a custom launcher</source>
        <translation>Пользовательский набор инструментов - это инструмент, используемый для создания пользовательского лаунчера</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="661"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="664"/>
        <source>%1 License</source>
        <translation>%1 Лицензия</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="671"/>
        <source>%1 Help</source>
        <translation>%1 Справка</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="722"/>
        <source>Could not write file: %1</source>
        <translation>Не удалось записать файл: %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="726"/>
        <source>File Removal Error</source>
        <translation>Ошибка удаления файла</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="726"/>
        <source>Could not remove file: %1</source>
        <translation>Не удалось удалить файл: %1</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/about.cpp" line="70"/>
        <source>License</source>
        <translation>Лицензия</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="71"/>
        <location filename="../src/about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>Список изменений</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>&amp;Закрыть</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="80"/>
        <source>This app can be used to create custom launchers: box of buttons/icons</source>
        <translation>Это приложение можно использовать для создания настраиваемых лаунчеров: бокс с кнопками/иконками</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="83"/>
        <source>Don&apos;t show &apos;show this dialog at startup&apos; checkbox</source>
        <translation>Не показывать чекбокс &quot;показывать этот диалог при запуске&quot;</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="85"/>
        <source>Full path and name of the .list file you want to load to set up the application</source>
        <translation>Полный путь и имя файла .list, который вы хотите загрузить для настройки приложения</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="95"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="96"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Программа запущена суперпользователем. Для использования программы войдите в систему как обычный пользователь.</translation>
    </message>
</context>
</TS>

==> custom-toolbox_25.11.tar.xz: BUILD/translations/custom-toolbox_ru_RU.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru_RU">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.ui" line="20"/>
        <location filename="../src/mainwindow.cpp" line="198"/>
        <source>Custom Toolbox</source>
        <translation>Пользовательский набор инструментов</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="63"/>
        <source>About this application</source>
        <translation>Об этом приложении</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="66"/>
        <source>About...</source>
        <translation>О программе...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="73"/>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="89"/>
        <source>Customize launcher</source>
        <translation>Настроить лаунчер</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="92"/>
        <source>Edit</source>
        <translation>Правка</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="99"/>
        <source>Alt+E</source>
        <translation>Alt+E</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="163"/>
        <source>Help</source>
        <translation>Помощь</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="170"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="183"/>
        <source>Close application</source>
        <translation>Закрыть приложение</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="186"/>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="193"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="308"/>
        <source>This is a custom launcher</source>
        <translation>Это настраиваемый лаунчер</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="324"/>
        <source>Show this dialog at start up</source>
        <translation>Показывать этот диалог при запуске</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="346"/>
        <source>search</source>
        <translation>поиск</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="250"/>
        <location filename="../src/mainwindow.cpp" line="257"/>
        <source>Execution Error</source>
        <translation>Ошибка выполнения</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="250"/>
        <source>Failed to execute command: %1</source>
        <translation>Не удалось выполнить команду: %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="257"/>
        <source>Failed to start program: %1</source>
        <translation>Не удалось запустить программу: %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="297"/>
        <source>Open List File</source>
        <translation>Открыть файл списка</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="297"/>
        <source>List Files (*.list)</source>
        <translation>Файлы списка (*.list)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="299"/>
        <source>File Selection Error</source>
        <translation>Ошибка выбора файла</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="299"/>
        <source>No file selected. Application will now exit.</source>
        <translation>Файл не выбран. Завершение приложения.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="305"/>
        <location filename="../src/mainwindow.cpp" line="569"/>
        <location filename="../src/mainwindow.cpp" line="722"/>
        <source>File Open Error</source>
        <translation>Ошибка открытия файла</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="306"/>
        <source>Could not open file. Do you want to try again?</source>
        <translation>Не могу открыть файл. Хотите попробовать еще раз?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="561"/>
        <source>File Not Found</source>
        <translation>Файл не найден</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="561"/>
        <source>The file %1 does not exist.</source>
        <translation>Файл %1 не существует.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="569"/>
        <source>Could not open file: </source>
        <translation>Не удалось открыть файл:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="660"/>
        <source>Version:</source>
        <translation>Версия:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="663"/>
        <source>About %1</source>
        <translation>О %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="661"/>
        <source>Custom Toolbox is a tool used for creating a custom launcher</source>
        <translation>Пользовательский набор инструментов - это инструмент, используемый для создания пользовательского лаунчера</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="661"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="664"/>
        <source>%1 License</source>
        <translation>%1 Лицензия</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="671"/>
        <source>%1 Help</source>
        <translation>%1 Справка</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="722"/>
        <source>Could not write file: %1</source>
        <translation>Не удалось записать файл: %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="726"/>
        <source>File Removal Error</source>
        <translation>Ошибка удаления файла</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="726"/>
        <source>Could not remove file: %1</source>
        <translation>Не удалось удалить файл: %1</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/about.cpp" line="70"/>
        <source>License</source>
        <translation>Лицензия</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="71"/>
        <location filename="../src/about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>Список изменений</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>&amp;Закрыть</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="80"/>
        <source>This app can be used to create custom launchers: box of buttons/icons</source>
        <translation>Это приложение можно использовать для создания настраиваемых лаунчеров: бокс с кнопками/иконками</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="83"/>
        <source>Don&apos;t show &apos;show this dialog at startup&apos; checkbox</source>
        <translation>Не показывать чекбокс &quot;показывать этот диалог при запуске&quot;</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="85"/>
        <source>Full path and name of the .list file you want to load to set up the application</source>
        <translation>Полный путь и имя файла .list, который вы хотите загрузить для настройки приложения</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="95"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="96"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Программа запущена суперпользователем. Для использования программы войдите в систему как обычный пользователь.</translation>
    </message>
</context>
</TS>
